@@ -293,7 +293,7 @@ def PySconsSetup(args=ARGUMENTS, tools=['default', PYTOOL()]):
     try: basename = args["temp"] 
     except: basename = None
 
-    bn = os.path.split(basename)
+    bn = list(os.path.split(basename))
     env.SConsignFile(os.path.join([".."] * (len(bn) - 1) + bn + [".sconsign"]))
 
     ftargets = [t + ".force" for t in targets]
